/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */

package org.apache.tuscany.sca.runtime;

import java.util.List;

import org.apache.tuscany.sca.invocation.InvocationChain;

/**
 * The runtime wire interface that connects a component reference to a 
 *  component service (or an external service) over the selected binding
 * 
 * @version $Rev: 539355 $ $Date: 2007-05-18 15:35:14 +0530 (Fri, 18 May 2007) $
 */
public interface RuntimeWire {

    /**
     * Get the source of the wire
     * 
     * @return The end point reference of the source
     */
    EndpointReference getSource();

    /**
     * Get the target of the wire
     * 
     * @return The end point reference of the target
     */
    EndpointReference getTarget();

    /**
     * Returns the invocation chains for service operations associated with the
     * wire
     * 
     * @return the invocation chains for service operations associated with the
     *         wire
     */
    List<InvocationChain> getInvocationChains();

    /**
     * Returns the invocation chains for callback service operations associated
     * with the wire
     * 
     * @return the invocation chains for callback service operations associated
     *         with the wire
     */
    List<InvocationChain> getCallbackInvocationChains();
   
}
