/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.    
 */
package org.osoa.sca;


/**
 * A ServiceReference represents a client's perspective of a reference to another service.
 *
 * @version $Rev: 507125 $ $Date: 2007-02-13 23:35:37 +0530 (Tue, 13 Feb 2007) $
 * @param <B> the Java interface associated with this reference
 */
public interface ServiceReference<B> extends CallableReference<B> {
    /**
     * Returns the id supplied by the user that will be associated with conversations initiated through this reference.
     *
     * @return the id to associated with any conversation initiated through this reference
     */
    Object getConversationID();

    /**
     * Set the id to associate with any conversation started through this reference.
     * If the value supplied is null then the id will be generated by the implementation.
     *
     * @param conversationId the user-defined id to associated with a conversation
     * @throws IllegalStateException if a conversation is currently associated with this reference
     */
    void setConversationID(Object conversationId) throws IllegalStateException;

    /**
     * Sets the callback ID.
     *
     * @param callbackID the callback ID
     */
    void setCallbackID(Object callbackID);

    /**
     * Returns the callback object.
     *
     * @return the callback object
     */
    Object getCallback();

    /**
     * Sets the callback object.
     *
     * @param callback the callback object
     */
    void setCallback(Object callback);
}
